@@ -19,7 +19,9 @@ import dbus.service
 import dbus.mainloop.glib
 
 from calculate.consolegui import qt
-import sudsds, time, sys
+# import sudsds, time, sys
+import time, sys
+from suds import MethodNotFound
 import os, pwd, shutil
 import ConfigParser
 
@@ -94,7 +96,8 @@ class SelectedMethodWgt(qt.QWidget):
                                      self.args.method + '_view', step = 0)
             view = self.ClientObj.client.service[0][self.args.method + \
                                 '_view'](int(self.ClientObj.sid), view_params)
-        except sudsds.MethodNotFound:
+        # except sudsds.MethodNotFound:
+        except MethodNotFound:
             _print('Method not found: ', self.args.method + '_view')
             self.close()
             sys.exit(1)
