@@ -15,7 +15,8 @@
 #  limitations under the License.
 
 from calculate.consolegui import qt
-from sudsds import WebFault
+# from sudsds import WebFault
+from suds import WebFault
 import logging, OpenSSL
 import ConfigParser, os, urllib2
 import getpass
@@ -166,7 +167,7 @@ class FrameConnection(qt.QWidget):
         
     # establish a connection
     def onClick(self):
-        print "DEBUG: onClick"
+        # print "DEBUG: onClick"
         self.setDisabled(True)
         if self.ClientObj.client:
             show_msg(_('You are connected to the server!')+'\n' + \
